package com.jz.dmp.modules.dao;

import com.jz.dmp.modules.model.DmpTable;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 项目表信息(DmpTable)表数据库访问层
 *
 * @author Bellamy
 * @since 2020-12-23 15:32:55
 */
public interface DmpTableDao {

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    DmpTable queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    List<DmpTable> queryAllByLimit(@Param("offset") int offset, @Param("limit") int limit);


    /**
     * 通过实体作为筛选条件查询
     *
     * @param dmpTable 实例对象
     * @return 对象列表
     */
    List<DmpTable> queryAll(DmpTable dmpTable);

    /**
     * 新增数据
     *
     * @param dmpTable 实例对象
     * @return 影响行数
     */
    int insert(DmpTable dmpTable);

    /**
     * 批量新增数据（MyBatis原生foreach方法）
     *
     * @param entities List<DmpTable> 实例对象列表
     * @return 影响行数
     */
    int insertBatch(@Param("entities") List<DmpTable> entities);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<DmpTable> 实例对象列表
     * @return 影响行数
     */
    int insertOrUpdateBatch(@Param("entities") List<DmpTable> entities);

    /**
     * 修改数据
     *
     * @param dmpTable 实例对象
     * @return 影响行数
     */
    int update(DmpTable dmpTable);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    int deleteTableColumnByName(DmpTable table);

    int deleteTableByName(DmpTable table);
}